-- MySQL dump 10.10
--
--
-- Current Database: `opcfg`
--

CREATE DATABASE /*!32312 IF NOT EXISTS*/ `opcfg` /*!40100 DEFAULT CHARACTER SET latin1 */;
ALTER DATABASE opcfg DEFAULT CHARSET = utf8;

USE `opcfg`;

--
-- Table structure for table `system_conf`
--

CREATE TABLE `system_conf` (
	`module` VARCHAR(100) NOT NULL,
	`var` VARCHAR(100) NOT NULL,
	`descr` VARCHAR(255) NOT NULL,
	`value` VARCHAR(255) NOT NULL,
	`default_value` VARCHAR(255) NOT NULL,
	PRIMARY KEY (`module`,`var`)
) DEFAULT CHARSET=utf8;

CREATE TABLE `service_metric` (
	`metric_id` int(11) NOT NULL auto_increment,
	`host_id` int(11) NOT NULL default '0',
	`service_id` int(11) NOT NULL default '0',
	`metric` varchar(75) NOT NULL default '',
	`unit` varchar(25) default NULL,
	`value_max` float default NULL,
	`value_min` float default NULL,
	PRIMARY KEY  (`host_id`,`service_id`,`metric`),
	KEY `metric_id` (`metric_id`),
	KEY `metric` (`metric`,`host_id`,`service_id`)
) DEFAULT CHARSET=utf8;

ALTER TABLE service_metric ADD COLUMN baseline_id INT(11) NOT NULL DEFAULT '0';

--
-- Table structure for table `changes`
--

CREATE TABLE `changes` (
  `type` varchar(10) NOT NULL default '',
  `to_change` text NOT NULL
) DEFAULT CHARSET=utf8;

ALTER TABLE `changes` CHANGE COLUMN `type` `type` int(11) NOT NULL;
ALTER TABLE `changes` CHANGE COLUMN `to_change` `to_change` varchar(64) NOT NULL;


--
-- Table structure for table `dbauth_users`
--
CREATE TABLE `dbauth_users` (
  `user_id` int(11) unsigned NOT NULL auto_increment,
  `username` varchar(50) NOT NULL default '',
  `password` text NOT NULL,
  `firstname` text,
  `lastname` text,
  `initials` varchar(5) default NULL,
  `displayname` text,
  `email` text NOT NULL,
  `pager` text,
  PRIMARY KEY  (`user_id`)
) DEFAULT CHARSET=utf8;


--
-- Table structure for table `history`
--
CREATE TABLE `history` (
  `id` int(11) NOT NULL auto_increment,
  `username` varchar(50) NOT NULL default '',
  `query` text NOT NULL,
  `ctime` datetime NOT NULL default '0000-00-00 00:00:00',
  PRIMARY KEY  (`id`)
) DEFAULT CHARSET=utf8;


--
-- Table structure for table `nagios_broker_modules`
--
CREATE TABLE `nagios_broker_modules` (
  `module_id` int(11) NOT NULL auto_increment,
  `module_line` text NOT NULL,
  PRIMARY KEY  (`module_id`)
) DEFAULT CHARSET=utf8;

ALTER IGNORE TABLE nagios_broker_modules ADD UNIQUE(module_line(200));

--
-- Table structure for table `nagios_cgi`
--
CREATE TABLE `nagios_cgi` (
  `physical_html_path` text,
  `url_html_path` text,
  `nagios_check_command` text,
  `use_authentication` enum('0','1') default NULL,
  `show_context_help` enum('0','1') default NULL,
  `default_user_name` text,
  `authorized_for_system_information` text,
  `authorized_for_system_commands` text,
  `authorized_for_configuration_information` text,
  `authorized_for_all_hosts` text,
  `authorized_for_all_host_commands` text,
  `authorized_for_all_services` text,
  `authorized_for_all_service_commands` text,
  `statusmap_background_image` text,
  `default_statusmap_layout` enum('0','1','2','3','4','5','6') default NULL,
  `statuswrl_include` text,
  `default_statuswrl_layout` enum('0','1','2','3','4') default NULL,
  `refresh_rate` int(5) default NULL,
  `host_unreachable_sound` text,
  `host_down_sound` text,
  `service_critical_sound` text,
  `service_warning_sound` text,
  `service_unknown_sound` text,
  `ping_syntax` text
) DEFAULT CHARSET=utf8;

ALTER TABLE nagios_cgi ADD main_config_file varchar(256);

--
-- Table structure for table `nagios_cgi_desc`
--
CREATE TABLE `nagios_cgi_desc` (
  `field_name` text NOT NULL,
  `field_desc` text NOT NULL
) DEFAULT CHARSET=utf8;


--
-- Table structure for table `nagios_commands`
--
CREATE TABLE `nagios_commands` (
  `command_id` int(11) unsigned NOT NULL auto_increment,
  `network_id` int(11) unsigned NOT NULL default '0',
  `command_name` text NOT NULL,
  `command_line` text NOT NULL,
  `command_desc` text,
  PRIMARY KEY  (`command_id`)
) DEFAULT CHARSET=utf8;

ALTER TABLE nagios_commands MODIFY COLUMN command_name varchar(128) UNIQUE;
DROP INDEX command_name_uniq on nagios_commands;
UPDATE nagios_commands SET command_line = 'echo "OK"' WHERE command_name = 'passive-check-service';
--
-- Column to indicate if a given command is system default and may not be changed
--
ALTER TABLE nagios_commands ADD COLUMN system int(11) default 0;


--
-- add new column to indicate command type(check, notification or event handler)
--
ALTER TABLE `nagios_commands` ADD COLUMN command_type int(11) DEFAULT 1;

--
-- SNMP discovery default check commands
--
INSERT INTO `nagios_commands` values(1,'0','system-discovery-snmp-load','$USER1$/opservices/op-snmp-load -h $HOSTADDRESS$:$_HOSTSNMP_PORT$ -i $_HOSTCOMMUNITY_ID$ -t $_HOSTSNMP_TIMEOUT$ -r $_HOSTSNMP_RETRIES$ -w $ARG1$ -c $ARG2$','Check cpu load average through snmp',1, 1);
INSERT INTO `nagios_commands` values(2,'0','system-discovery-snmp-load-unix','$USER1$/opservices/op-snmp-load-unix -h $HOSTADDRESS$:$_HOSTSNMP_PORT$ -i $_HOSTCOMMUNITY_ID$ -t $_HOSTSNMP_TIMEOUT$ -r $_HOSTSNMP_RETRIES$ -w $ARG1$ -c $ARG2$','Check unix cpu load average through snmp',1, 1);
INSERT INTO `nagios_commands` values(3,'0','system-discovery-snmp-process','$USER1$/opservices/op-snmp-process -h $HOSTADDRESS$:$_HOSTSNMP_PORT$ -i $_HOSTCOMMUNITY_ID$ -t $_HOSTSNMP_TIMEOUT$ -r $_HOSTSNMP_RETRIES$ -f $ARG1$','Check if ARG1 process is running on target server',1, 1);
INSERT INTO `nagios_commands` values(4,'0','system-discovery-snmp-storage','$USER1$/opservices/op-snmp-storage -h $HOSTADDRESS$:$_HOSTSNMP_PORT$ -i $_HOSTCOMMUNITY_ID$ -t $_HOSTSNMP_TIMEOUT$ -r $_HOSTSNMP_RETRIES$ -f $ARG1$ -w $ARG2$ -c $ARG3$','Check ARG1 storage usage. ARG1 may be disk, memory or virtual memory',1, 1);
INSERT INTO `nagios_commands` values(5,'0','system-discovery-snmp-winservice','$USER1$/opservices/op-snmp-winservice -h $HOSTADDRESS$:$_HOSTSNMP_PORT$ -i $_HOSTCOMMUNITY_ID$ -t $_HOSTSNMP_TIMEOUT$ -r $_HOSTSNMP_RETRIES$ -f $ARG1$','Check if ARG1 service is running.',1, 1);
INSERT INTO `nagios_commands` values(6,'0','system-discovery-tcp-port','$USER1$/check_tcp -H $HOSTADDRESS$ -p $ARG1$','Check if ARG1 tcp port is listening.',1, 1);
INSERT INTO `nagios_commands` values(7,'0','system-discovery-icmp','$USER1$/check_icmp -H $HOSTADDRESS$','Check if HOSTADDRESS answers through ICMP.',1, 1);
INSERT INTO `nagios_commands` values(8,'0','system-discovery-snmp-interface','$USER1$/opservices/op-snmp-interface -h $HOSTADDRESS$:$_HOSTSNMP_PORT$ -i $_HOSTCOMMUNITY_ID$ -t $_HOSTSNMP_TIMEOUT$ -r $_HOSTSNMP_RETRIES$ -m $ARG1$ -I $ARG2$ -s $ARG3$ -w $ARG4$ -c $ARG5$ -W $ARG6$ -C $ARG7$ -x $ARG8$ -b $ARG9$','Check interface network utilization',1, 1);
INSERT INTO `nagios_commands` values(9,'0','system-discovery-snmp-uptime','$USER1$/opservices/op-snmp-uptime -h $HOSTADDRESS$:$_HOSTSNMP_PORT$ -i $_HOSTCOMMUNITY_ID$ -t $_HOSTSNMP_TIMEOUT$ -r $_HOSTSNMP_RETRIES$ -c $ARG1$','Check uptime through snmp',1, 1);
INSERT INTO `nagios_commands` values(10,'0','system-discovery-notification-service','$USER1$/notify_by_email.pl -e service','Default notification for contacts created through wizard or discovery',1, 2);
INSERT INTO `nagios_commands` values(11,'0','system-discovery-notification-host','$USER1$/notify_by_email.pl -e host','Default notification for contacts created through wizard or discovery',1, 2);
INSERT INTO `nagios_commands` values(12,'0','system-discovery-telnet-switch-backup','$USER1$/opservices/telnet_switch_backup.php -H $HOSTNAME$ -i $ARG1$ -m $ARG2$ -p $ARG3$','Used to create a configuration backup of the switch by telnet.',1, 1);
INSERT INTO `nagios_commands` values(13,'0','system-discovery-ssh-switch-backup','$USER1$/opservices/ssh_switch_backup.php -H $HOSTNAME$ -i $ARG1$ -m $ARG2$ -p $ARG3$','Used to create a configuration backup of the switch by ssh.',1, 1);

---
--- remove old command with no parameters and add the new one
---
DELETE FROM `nagios_commands` WHERE command_name='system-notify-qualitor';
INSERT INTO `nagios_commands` VALUES (14,0,'system-notify-qualitor','/usr/local/opmon/libexec/open-ticket-qualitor.php \'$HOSTNAME$\' \'$HOSTADDRESS$\' \'$HOSTSTATE$\' \'$HOSTOUTPUT$\' \'$HOSTACKAUTHOR$\' \'$HOSTACKCOMMENT$\' \'$HOSTGROUPNAMES$\' \'$SERVICEDESC$\' \'$SERVICESTATE$\' \'$SERVICEOUTPUT$\' \'$SERVICEACKAUTHOR$\' \'$SERVICEACKCOMMENT$\' \'$SERVICEGROUPNAMES$\' \'$CONTACTNAME$\' \'$_HOSTHOST_ID$\' \'$_SERVICESERVICE_ID$\'','Qualitor plugins that use parameters test',1,2);

INSERT INTO `nagios_commands` values(15,'0','system-notify-otrs','$USER1$/open-ticket-otrs.php','Manage tickets on OTRS servicedesk',1, 2);
INSERT INTO `nagios_commands` values(NULL,'0','system-notify-by-onc','$USER1$/opservices/notify-by-onc','Notify by ONC',1, 2);
INSERT INTO `nagios_commands` VALUES(NULL,'0','op-baseline-cmd','\$USER1\$/opservices/opbaseline \$ARG1\$ \$ARG2\$ \$ARG3\$ \$ARG4\$ \$ARG5\$ \$ARG6\$','Calculate Holt-Winters',1, 1);
INSERT INTO `nagios_commands` VALUES(NULL,'0','notify-by-OpAlert','$USER1$/notify_by_opalert.pl -t \'$CONTACTPAGER$\' -e service','Notificação de servico via modem gsm',0, 2);
INSERT INTO `nagios_commands` VALUES(NULL,'0','host-notify-by-OpAlert','$USER1$/notify_by_opalert.pl -t \'$CONTACTPAGER$\' -e host','Notificação de host via modem gsm',0, 2);
INSERT INTO `nagios_commands` VALUES(NULL,'0','notify-by-Zenvia','$USER1$/opservices/notify_by_zenvia.pl -t \'$CONTACTPAGER$\' -e service -U \'\' -P \'\' -f opmon','Notificação de servico via Zenvia',0, 2);
INSERT INTO `nagios_commands` VALUES(NULL,'0','host-notify-by-Zenvia','$USER1$/opservices/notify_by_zenvia.pl -t \'$CONTACTPAGER$\' -e host -U \'\' -P \'\' -f opmon','Notificação de via Zenvia',0, 2);
INSERT INTO `nagios_commands` VALUES(NULL,'0','notify-by-Comunika','$USER1$/notify_by_comunika.pl -t \'$CONTACTPAGER$\' -e service -U \'\' -P \'\'','Notificação de servico via Comunika',0, 2);
INSERT INTO `nagios_commands` VALUES(NULL,'0','host-notify-by-Comunika','$USER1$/notify_by_comunika.pl -t \'$CONTACTPAGER$\' -e host -U \'\' -P \'\'','Notificação de host via Comunika',0, 2);
INSERT INTO `nagios_commands` VALUES(NULL,'0','check_opcem_32bits','$USER1$/opservices/check_opcem.pl -H $ARG1$ -p 5666 -P "C:\\Program Files\\OpCEM\\Resources\\robots\\$SERVICEDESC$" -c 50m','Check OpCEM agent return',1,1);
INSERT INTO `nagios_commands` VALUES(NULL,'0','check_opcem_64bits','$USER1$/opservices/check_opcem.pl -H $ARG1$ -p 5666 -P "C:\\Program Files (x86)\\OpCEM\\Resources\\robots\\$SERVICEDESC$" -c 50m','Check OpCEM agent return',1,1);
INSERT INTO `nagios_commands` VALUES(NULL,'0','system-check_dummy','$USER1$/check_dummy $ARG1$','Check dummy for passive checks',1,1);
INSERT INTO `nagios_commands` VALUES(NULL, 0,'ext_ping','/bin/ping -c 5 $HOSTADDRESS$', NULL, 0, 4);
INSERT INTO `nagios_commands` VALUES(NULL, 0,'check_ionic_status','$USER1$/opservices/check_ionic_status.php', 'Verify if is possible access ionic web service.', 0, 1);

UPDATE `nagios_commands` set command_line='\$USER1\$/opservices/opbaseline -H \$ARG1\$ -s \$ARG2\$ -t \$ARG3\$ -i \$ARG4\$ -C \$ARG5\$ \$ARG6\$ \$ARG7\$' where command_name='op-baseline-cmd';

--
-- Table structure for table `nagios_commands_desc`
--
CREATE TABLE `nagios_commands_desc` (
  `field_name` text NOT NULL,
  `field_desc` text NOT NULL
) DEFAULT CHARSET=utf8;

--
-- Table structure for table `nagios_contact_addresses`
--
CREATE TABLE `nagios_contact_addresses` (
  `contactaddress_id` int(11) unsigned NOT NULL auto_increment,
  `contact_id` int(11) unsigned NOT NULL default '0',
  `address` text NOT NULL,
  PRIMARY KEY  (`contactaddress_id`)
) DEFAULT CHARSET=utf8;


--
-- Table structure for table `nagios_contactgroup_membership`
--
CREATE TABLE `nagios_contactgroup_membership` (
  `contactgroup_id` int(11) unsigned NOT NULL default '0',
  `contact_id` int(11) unsigned NOT NULL default '0',
  PRIMARY KEY  (`contactgroup_id`,`contact_id`)
) DEFAULT CHARSET=utf8;

--
-- Table structure for table `nagios_contactgroups`
--
CREATE TABLE `nagios_contactgroups` (
  `contactgroup_id` int(11) unsigned NOT NULL auto_increment,
  `network_id` int(11) unsigned NOT NULL default '0',
  `contactgroup_name` text NOT NULL,
  `alias` text NOT NULL,
  PRIMARY KEY  (`contactgroup_id`)
) DEFAULT CHARSET=utf8;

--
-- Dumping data for table `nagios_contactgroups`
--
ALTER TABLE nagios_contactgroups MODIFY COLUMN contactgroup_name varchar(128) UNIQUE;
DROP INDEX name ON nagios_contactgroups;
ALTER TABLE nagios_contactgroups MODIFY COLUMN alias varchar(256);


--
-- Table structure for table `nagios_contactgroups_desc`
--
CREATE TABLE `nagios_contactgroups_desc` (
  `field_name` text NOT NULL,
  `field_desc` text NOT NULL
) DEFAULT CHARSET=utf8;


--
-- Table structure for table `nagios_contacts`
--
CREATE TABLE `nagios_contacts` (
  `contact_id` int(11) unsigned NOT NULL auto_increment,
  `alias` text,
  `host_notification_period` int(11) unsigned NOT NULL default '0',
  `service_notification_period` int(11) unsigned NOT NULL default '0',
  `email` text,
  `pager` text,
  `host_notification_options_down` enum('0','1') NOT NULL default '0',
  `host_notification_options_unreachable` enum('0','1') NOT NULL default '0',
  `host_notification_options_recovery` enum('0','1') NOT NULL default '0',
  `service_notification_options_warning` enum('0','1') NOT NULL default '0',
  `service_notification_options_unknown` enum('0','1') NOT NULL default '0',
  `service_notification_options_critical` enum('0','1') NOT NULL default '0',
  `service_notification_options_recovery` enum('0','1') NOT NULL default '0',
  `host_notification_options_flapping` enum('0','1') NOT NULL default '0',
  `service_notification_options_flapping` enum('0','1') NOT NULL default '0',
  `contact_name` text NOT NULL,
  `command_execution` int(11) NOT NULL default '0',
  PRIMARY KEY  (`contact_id`)
) DEFAULT CHARSET=utf8;

--
-- fields adjustments for nagios_contacts
--
ALTER TABLE nagios_contacts MODIFY COLUMN alias varchar(256);
ALTER TABLE nagios_contacts MODIFY COLUMN contact_name varchar(128) UNIQUE;
DROP INDEX name ON nagios_contacts;
ALTER TABLE nagios_contacts DROP COLUMN `language_id`;
ALTER TABLE nagios_contacts ADD COLUMN `external_auth` int(11) NOT NULL DEFAULT 0;
ALTER TABLE nagios_contacts ADD COLUMN `type` enum('0', '1', '2') NOT NULL default '2';
ALTER TABLE nagios_contacts ADD COLUMN `password` varchar(255);
ALTER TABLE nagios_contacts ADD COLUMN `language` varchar(32) NOT NULL default 'en_US';

-- adds menu permission columns
ALTER TABLE nagios_contacts add column tab_dashboard int(11);
ALTER TABLE nagios_contacts add column tab_scat int(11);
ALTER TABLE nagios_contacts add column tab_report int(11);
ALTER TABLE nagios_contacts add column tab_monitoring int(11);
ALTER TABLE nagios_contacts add column tab_network int(11);
ALTER TABLE nagios_contacts add column tab_additionalmodule int(11);
ALTER TABLE nagios_contacts add column tab_tool int(11);

-- remove old columns
ALTER TABLE nagios_contacts DROP COLUMN `tab_maps`;
ALTER TABLE nagios_contacts DROP COLUMN `tab_tools`;
ALTER TABLE nagios_contacts DROP COLUMN `tab_additionalmodules`;
ALTER TABLE nagios_contacts DROP COLUMN `tab_documentations`;
ALTER TABLE nagios_contacts DROP COLUMN `tab_reports`;
ALTER TABLE nagios_contacts DROP COLUMN `tab_scats`;
ALTER TABLE nagios_contacts DROP COLUMN `tab_documentation`;


ALTER TABLE nagios_contacts add column `theme` varchar(64) not null default 'default';
ALTER TABLE nagios_contacts add expire_time datetime default NULL;
ALTER TABLE nagios_contacts add column show_splashscreen int(1) not null default '1';
ALTER TABLE nagios_contacts add column `host_notification_options_downtime` enum('0','1') NOT NULL default '0';
ALTER TABLE nagios_contacts add column `service_notification_options_downtime` enum('0','1') NOT NULL default '0';
-- ALTER TABLE nagios_contacts add column `_token` varchar(512) default NULL;

--
-- Extra indexes for dump speedy up for nagios_contacts
--
CREATE INDEX contact_id on nagios_contacts_notification_commands (contact_id);
CREATE INDEX command_id on nagios_contacts_notification_commands (command_id, contact_id, notification_type);

-- menu permissions adjustment
UPDATE nagios_contacts set tab_dashboard = 7 WHERE contact_name = 'opmonadmin';
UPDATE nagios_contacts set tab_scat = 3 WHERE contact_name = 'opmonadmin';
UPDATE nagios_contacts set tab_report = 31 WHERE contact_name = 'opmonadmin';
UPDATE nagios_contacts set tab_monitoring = 255 WHERE contact_name = 'opmonadmin';
UPDATE nagios_contacts set tab_network = 15 WHERE contact_name = 'opmonadmin';
UPDATE nagios_contacts set tab_tool = 127 WHERE contact_name = 'opmonadmin';

-- set permission for new menu arrangement
UPDATE nagios_contacts set tab_network = 15;
UPDATE nagios_contacts set tab_monitoring = 255;

--
-- Table structure for table `nagios_contacts_desc`
--
CREATE TABLE `nagios_contacts_desc` (
  `field_name` text NOT NULL,
  `field_desc` text NOT NULL
) DEFAULT CHARSET=utf8;

--
-- Table structure for table `nagios_contacts_notification_commands`
--
CREATE TABLE `nagios_contacts_notification_commands` (
  `contact_notification_command_id` int(11) unsigned NOT NULL auto_increment,
  `contact_id` int(11) unsigned NOT NULL default '0',
  `command_id` int(11) unsigned NOT NULL default '0',
  `notification_type` enum('host','service') NOT NULL default 'host',
  PRIMARY KEY  (`contact_notification_command_id`)
) DEFAULT CHARSET=utf8;


--
-- Table structure for table `nagios_dependencies`
--
CREATE TABLE `nagios_dependencies` (
  `dependency_id` int(11) unsigned NOT NULL auto_increment,
  `host_id` int(11) default NULL,
  `host_template_id` int(11) unsigned default NULL,
  `service_template_id` int(11) unsigned default NULL,
  `service_id` int(11) unsigned default NULL,
  `target_host_id` int(11) unsigned default NULL,
  `target_service_id` int(11) unsigned default NULL,
  `inherits_parent` enum('0','1') default NULL,
  `execution_failure_criteria_up` enum('0','1') default NULL,
  `execution_failure_criteria_down` enum('0','1') default NULL,
  `execution_failure_criteria_unreachable` enum('0','1') default NULL,
  `execution_failure_criteria_pending` enum('0','1') default NULL,
  `execution_failure_criteria_ok` enum('0','1') default NULL,
  `execution_failure_criteria_warning` enum('0','1') default NULL,
  `execution_failure_criteria_unknown` enum('0','1') default NULL,
  `execution_failure_criteria_critical` enum('0','1') default NULL,
  `notification_failure_criteria_ok` enum('0','1') default NULL,
  `notification_failure_criteria_warning` enum('0','1') default NULL,
  `notification_failure_criteria_unknown` enum('0','1') default NULL,
  `notification_failure_criteria_critical` enum('0','1') default NULL,
  `notification_failure_criteria_pending` enum('0','1') default NULL,
  `notification_failure_criteria_up` enum('0','1') default NULL,
  `notification_failure_criteria_down` enum('0','1') default NULL,
  `notification_failure_criteria_unreachable` enum('0','1') default NULL,
  PRIMARY KEY  (`dependency_id`)
) DEFAULT CHARSET=utf8;

--
-- Table structure for table `nagios_dependency_desc`
--
CREATE TABLE `nagios_dependency_desc` (
  `field_name` text NOT NULL,
  `field_desc` text NOT NULL
) DEFAULT CHARSET=utf8;

--
-- Table structure for table `nagios_escalation_contactgroups`
--
CREATE TABLE `nagios_escalation_contactgroups` (
  `escalation_id` int(11) unsigned NOT NULL default '0',
  `contactgroup_id` int(11) unsigned NOT NULL default '0'
) DEFAULT CHARSET=utf8;

--
-- Table structure for table `nagios_escalations`
--
CREATE TABLE `nagios_escalations` (
  `escalation_id` int(11) unsigned NOT NULL auto_increment,
  `escalation_description` text NOT NULL,
  `host_id` int(11) default NULL,
  `host_template_id` int(11) unsigned default NULL,
  `service_template_id` int(11) unsigned default NULL,
  `service_id` int(11) unsigned default NULL,
  `first_notification` int(4) default NULL,
  `last_notification` varchar(4) default NULL,
  `notification_interval` int(8) default NULL,
  `escalation_period` int(11) unsigned default NULL,
  `escalation_options_up` enum('0','1') default NULL,
  `escalation_options_down` enum('0','1') default NULL,
  `escalation_options_unreachable` enum('0','1') default NULL,
  `escalation_options_ok` enum('0','1') default NULL,
  `escalation_options_warning` enum('0','1') default NULL,
  `escalation_options_unknown` enum('0','1') default NULL,
  `escalation_options_critical` enum('0','1') default NULL,
  PRIMARY KEY  (`escalation_id`)
) DEFAULT CHARSET=utf8;

--
-- Table structure for table `nagios_escalations_desc`
--
CREATE TABLE `nagios_escalations_desc` (
  `field_name` text NOT NULL,
  `field_desc` text NOT NULL
) DEFAULT CHARSET=utf8;


--
-- Table structure for table `nagios_host_contactgroups`
--
CREATE TABLE `nagios_host_contactgroups` (
  `host_id` int(11) unsigned NOT NULL default '0',
  `contactgroup_id` int(11) unsigned NOT NULL default '0',
  PRIMARY KEY  (`host_id`,`contactgroup_id`)
) DEFAULT CHARSET=utf8;

--
-- Table structure for table `nagios_host_contacts`
--
CREATE TABLE `nagios_host_contacts` (
  `host_id` int(11) unsigned NOT NULL default '0',
  `contact_id` int(11) unsigned NOT NULL default '0',
  PRIMARY KEY  (`host_id`,`contact_id`),
  KEY contact_id (`contact_id`,`host_id`)
) DEFAULT CHARSET=utf8;

--
-- Table structure for table `nagios_host_parents`
--

CREATE TABLE `nagios_host_parents` (
  `child_id` int(11) NOT NULL default '0',
  `parent_id` int(11) NOT NULL default '0'
) DEFAULT CHARSET=utf8;

--
-- Table structure for table `nagios_host_template_contactgroups`
--
CREATE TABLE `nagios_host_template_contactgroups` (
  `host_template_id` int(11) unsigned NOT NULL default '0',
  `contactgroup_id` int(11) unsigned NOT NULL default '0',
  PRIMARY KEY  (`host_template_id`,`contactgroup_id`)
) DEFAULT CHARSET=utf8;

--
-- Table structure for table `nagios_host_template_contacts`
--
CREATE TABLE `nagios_host_template_contacts` (
  `host_template_id` int(11) unsigned NOT NULL default '0',
  `contact_id` int(11) unsigned NOT NULL default '0',
  PRIMARY KEY  (`host_template_id`,`contact_id`),
  KEY  contact_id (`contact_id`,`host_template_id`)
) DEFAULT CHARSET=utf8;

--
-- Table structure for table `nagios_host_template_extended_info`
--
CREATE TABLE `nagios_host_template_extended_info` (
  `host_template_id` int(11) unsigned NOT NULL default '0',
  `notes` text,
  `notes_url` text,
  `action_url` text,
  `icon_image` text,
  `icon_image_alt` text,
  `vrml_image` text,
  `statusmap_image` text,
  `two_d_coords` text,
  `three_d_coords` text,
  PRIMARY KEY  (`host_template_id`)
) DEFAULT CHARSET=utf8;

--
-- Table structure for table `nagios_host_templates`
--
CREATE TABLE `nagios_host_templates` (
  `host_template_id` int(11) unsigned NOT NULL auto_increment,
  `use_template_id` int(11) unsigned default NULL,
  `template_name` text NOT NULL,
  `template_description` text NOT NULL,
  `check_command` int(11) unsigned default NULL,
  `max_check_attempts` int(2) default NULL,
  `check_interval` int(8) default NULL,
  `passive_checks_enabled` enum('0','1') default NULL,
  `check_period` int(11) unsigned default NULL,
  `obsess_over_host` enum('0','1') default NULL,
  `check_freshness` enum('0','1') default NULL,
  `freshness_threshold` int(8) default NULL,
  `active_checks_enabled` enum('0','1') default NULL,
  `checks_enabled` enum('0','1') default NULL,
  `event_handler` int(11) default NULL,
  `event_handler_enabled` enum('0','1') default NULL,
  `low_flap_threshold` int(6) default NULL,
  `high_flap_threshold` int(6) default NULL,
  `flap_detection_enabled` enum('0','1') default NULL,
  `process_perf_data` enum('0','1') default NULL,
  `retain_status_information` enum('0','1') default NULL,
  `retain_nonstatus_information` enum('0','1') default NULL,
  `notification_interval` int(8) default NULL,
  `notification_period` int(11) unsigned default NULL,
  `notifications_enabled` enum('0','1') default NULL,
  `notification_options_down` enum('0','1') default NULL,
  `notification_options_unreachable` enum('0','1') default NULL,
  `notification_options_recovery` enum('0','1') default NULL,
  `notification_options_flapping` enum('0','1') default NULL,
  `stalking_options_up` enum('0','1') default NULL,
  `stalking_options_down` enum('0','1') default NULL,
  `stalking_options_unreachable` enum('0','1') default NULL,
  `failure_prediction_enabled` enum('0','1') default NULL,
  PRIMARY KEY  (`host_template_id`)
) DEFAULT CHARSET=utf8;

--
-- Dumping data for table `nagios_host_templates`
--
ALTER TABLE nagios_host_templates MODIFY COLUMN template_name varchar(128) UNIQUE;
DROP INDEX name ON nagios_host_templates;
ALTER TABLE nagios_host_templates MODIFY COLUMN template_description varchar(256);
ALTER TABLE nagios_host_templates ADD retry_interval int(8) default NULL;
ALTER TABLE nagios_host_templates ADD _preffix varchar(32) default NULL;
ALTER TABLE nagios_host_templates ADD notification_options_downtime enum('0','1') default NULL;

--
-- Table structure for table `nagios_hostgroup_membership`
--
CREATE TABLE `nagios_hostgroup_membership` (
  `hostgroup_id` int(11) unsigned NOT NULL default '0',
  `host_id` int(11) unsigned NOT NULL default '0',
  PRIMARY KEY  (`hostgroup_id`,`host_id`)
) DEFAULT CHARSET=utf8;

--
-- Table structure for table `nagios_hostgroup_template_membership`
--
CREATE TABLE `nagios_hostgroup_template_membership` (
  `hostgroup_id` int(11) unsigned NOT NULL default '0',
  `host_template_id` int(11) unsigned NOT NULL default '0'
) DEFAULT CHARSET=utf8;

--
-- Table structure for table `nagios_hostgroups`
--
CREATE TABLE `nagios_hostgroups` (
  `hostgroup_id` int(11) unsigned NOT NULL auto_increment,
  `network_id` int(11) unsigned NOT NULL default '0',
  `hostgroup_name` text NOT NULL,
  `alias` text NOT NULL,
  `in_map` int(11) default NULL,
  PRIMARY KEY  (`hostgroup_id`)
) DEFAULT CHARSET=utf8;

--
-- Dumping data for table `nagios_hostgroups`
--
ALTER TABLE nagios_hostgroups MODIFY COLUMN hostgroup_name varchar(128) UNIQUE;
DROP INDEX name ON nagios_hostgroups;
ALTER TABLE nagios_hostgroups MODIFY COLUMN alias varchar(256);

--
-- Table structure for table `nagios_hostgroups_desc`
--
CREATE TABLE `nagios_hostgroups_desc` (
  `field_name` text NOT NULL,
  `field_desc` text NOT NULL
) DEFAULT CHARSET=utf8;

--
-- Table structure for table `nagios_hosts`
--
CREATE TABLE `nagios_hosts` (
  `host_id` int(11) unsigned NOT NULL auto_increment,
  `use_template_id` int(11) unsigned default NULL,
  `host_name` text NOT NULL,
  `alias` text NOT NULL,
  `address` text NOT NULL,
  `parents` int(11) unsigned default NULL,
  `check_command` int(11) unsigned default NULL,
  `max_check_attempts` int(2) default NULL,
  `check_interval` int(8) default NULL,
  `passive_checks_enabled` enum('0','1') default NULL,
  `check_period` int(11) unsigned default NULL,
  `obsess_over_host` enum('0','1') default NULL,
  `check_freshness` enum('0','1') default NULL,
  `freshness_threshold` int(8) default NULL,
  `active_checks_enabled` enum('0','1') default NULL,
  `checks_enabled` enum('0','1') default NULL,
  `event_handler` int(11) default NULL,
  `event_handler_enabled` enum('0','1') default NULL,
  `low_flap_threshold` int(6) default NULL,
  `high_flap_threshold` int(6) default NULL,
  `flap_detection_enabled` enum('0','1') default NULL,
  `process_perf_data` enum('0','1') default NULL,
  `retain_status_information` enum('0','1') default NULL,
  `retain_nonstatus_information` enum('0','1') default NULL,
  `notification_interval` int(8) default NULL,
  `notification_period` int(11) unsigned default NULL,
  `notifications_enabled` enum('0','1') default NULL,
  `notification_options_down` enum('0','1') default NULL,
  `notification_options_unreachable` enum('0','1') default NULL,
  `notification_options_recovery` enum('0','1') default NULL,
  `notification_options_flapping` enum('0','1') default NULL,
  `stalking_options_up` enum('0','1') default NULL,
  `stalking_options_down` enum('0','1') default NULL,
  `stalking_options_unreachable` enum('0','1') default NULL,
  `failure_prediction_enabled` enum('0','1') default NULL,
  PRIMARY KEY  (`host_id`)
) DEFAULT CHARSET=utf8;

--
-- Dumping data for table `nagios_hosts`
--
ALTER TABLE nagios_hosts MODIFY COLUMN host_name varchar(128);
ALTER TABLE nagios_hosts MODIFY COLUMN alias varchar(256);
ALTER TABLE nagios_hosts MODIFY COLUMN address varchar(256);
ALTER TABLE nagios_hosts ADD retry_interval int(8) default NULL;
ALTER TABLE nagios_hosts ADD snmp_timeout int(8) default 2;
ALTER TABLE nagios_hosts ADD snmp_retries int(8) default 2;
ALTER TABLE nagios_hosts ADD UNIQUE host_name_unique (host_name);
ALTER TABLE nagios_hosts ADD COLUMN snmp_port int(6) default 161;
ALTER TABLE nagios_hosts DROP COLUMN `snmp_v3`;
ALTER TABLE nagios_hosts ADD COLUMN `community_id` int(11) default NULL;
ALTER TABLE nagios_hosts ADD notification_options_downtime enum('0','1') default NULL;
ALTER TABLE nagios_hosts ADD `credential_id` INT(11) UNSIGNED DEFAULT NULL;
ALTER TABLE nagios_hosts ADD COLUMN `created` TIMESTAMP DEFAULT CURRENT_TIMESTAMP;

UPDATE nagios_hosts SET host_name=trim(host_name);
-- Fix miss configurations from Discovery
UPDATE nagios_hosts set event_handler = NULL WHERE event_handler = 0;
UPDATE nagios_services set event_handler = NULL WHERE event_handler = 0;
UPDATE nagios_hosts set retain_nonstatus_information = '1';
UPDATE nagios_services set retain_nonstatus_information = '1';
UPDATE nagios_hosts set stalking_options_up = NULL, stalking_options_down = NULL, stalking_options_unreachable = NULL;
UPDATE nagios_services set stalking_options_ok = NULL, stalking_options_warning = NULL, stalking_options_unknown = NULL, stalking_options_critical = NULL;
UPDATE nagios_hosts SET created=CURRENT_TIMESTAMP WHERE created='0000-00-00 00:00:00';

--
-- Table structure for table `nagios_hosts_check_command_parameters`
--
CREATE TABLE `nagios_hosts_check_command_parameters` (
  `checkcommandparameter_id` int(11) unsigned NOT NULL auto_increment,
  `host_id` int(11) unsigned default NULL,
  `host_template_id` int(11) unsigned default NULL,
  `parameter` text NOT NULL,
  PRIMARY KEY  (`checkcommandparameter_id`)
) DEFAULT CHARSET=utf8;

--
-- Dumping data for table `nagios_hosts_check_command_parameters`
--
ALTER TABLE nagios_hosts_check_command_parameters CHANGE parameter parameter text;


--
-- Table structure for table `nagios_hosts_desc`
--
CREATE TABLE `nagios_hosts_desc` (
  `field_name` text NOT NULL,
  `field_desc` text NOT NULL
) DEFAULT CHARSET=utf8;

--
-- Table structure for table `nagios_hosts_extended_info`
--
CREATE TABLE `nagios_hosts_extended_info` (
  `host_id` int(11) unsigned NOT NULL default '0',
  `notes` text,
  `notes_url` text,
  `action_url` text,
  `icon_image` text,
  `icon_image_alt` text,
  `vrml_image` text,
  `statusmap_image` text,
  `two_d_coords` text NOT NULL,
  `three_d_coords` text,
  PRIMARY KEY  (`host_id`)
) DEFAULT CHARSET=utf8;

--
-- Table structure for table `nagios_hosts_extended_info_desc`
--
CREATE TABLE `nagios_hosts_extended_info_desc` (
  `field_name` text NOT NULL,
  `field_desc` text NOT NULL
) DEFAULT CHARSET=utf8;

--
-- Table structure for table `nagios_main`
--
CREATE TABLE `nagios_main` (
  `config_dir` text,
  `log_file` text,
  `temp_file` text,
  `status_file` text,
  `aggregate_status_updates` enum('0','1') default NULL,
  `status_update_interval` int(11) default NULL,
  `nagios_user` varchar(24) default NULL,
  `nagios_group` varchar(24) default NULL,
  `enable_notifications` enum('0','1') default NULL,
  `execute_service_checks` enum('0','1') default NULL,
  `accept_passive_service_checks` enum('0','1') default NULL,
  `enable_event_handlers` enum('0','1') default NULL,
  `log_rotation_method` enum('n','h','d','w','m') default NULL,
  `log_archive_path` text,
  `check_external_commands` enum('0','1') default NULL,
  `command_check_interval` varchar(20) default NULL,
  `command_file` text,
  `downtime_file` text,
  `comment_file` text,
  `lock_file` text,
  `p1_file` text,
  `retain_state_information` enum('0','1') default NULL,
  `state_retention_file` text,
  `retention_update_interval` int(4) default NULL,
  `use_retained_program_state` enum('0','1') default '1',
  `use_syslog` enum('0','1') default NULL,
  `log_notifications` enum('0','1') default NULL,
  `log_service_retries` enum('0','1') default NULL,
  `log_host_retries` enum('0','1') default NULL,
  `log_event_handlers` enum('0','1') default NULL,
  `log_initial_states` enum('0','1') default NULL,
  `log_external_commands` enum('0','1') default NULL,
  `log_passive_checks` enum('0','1') default NULL,
  `global_host_event_handler` text,
  `global_service_event_handler` text,
  `sleep_time` float default NULL,
  `service_interleave_factor` enum('s','x') default NULL,
  `max_concurrent_checks` int(20) default NULL,
  `service_reaper_frequency` int(20) default NULL,
  `interval_length` int(20) default NULL,
  `use_aggressive_host_checking` enum('0','1') default NULL,
  `enable_flap_detection` enum('0','1') default NULL,
  `low_service_flap_threshold` float default NULL,
  `high_service_flap_threshold` float default NULL,
  `low_host_flap_threshold` float default NULL,
  `high_host_flap_threshold` float default NULL,
  `soft_state_dependencies` enum('0','1') default NULL,
  `service_check_timeout` int(8) default NULL,
  `host_check_timeout` int(8) default NULL,
  `event_handler_timeout` int(8) default NULL,
  `notification_timeout` int(8) default NULL,
  `ocsp_timeout` int(8) default NULL,
  `perfdata_timeout` int(20) default NULL,
  `obsess_over_services` enum('0','1') default NULL,
  `ocsp_command` int(11) default NULL,
  `process_performance_data` enum('0','1') default NULL,
  `check_for_orphaned_services` enum('0','1') default NULL,
  `check_service_freshness` enum('0','1') default NULL,
  `freshness_check_interval` int(20) default NULL,
  `date_format` enum('us','euro','iso8601','strict-iso8601') default NULL,
  `illegal_object_name_chars` text,
  `illegal_macro_output_chars` text,
  `admin_email` text,
  `admin_pager` text,
  `object_cache_file` text,
  `execute_host_checks` enum('0','1') default NULL,
  `service_inter_check_delay_method` text,
  `use_retained_scheduling_info` enum('0','1') default '1',
  `accept_passive_host_checks` enum('0','1') default NULL,
  `max_service_check_spread` int(2) default NULL,
  `host_inter_check_delay_method` text,
  `max_host_check_spread` int(2) default NULL,
  `auto_reschedule_checks` enum('0','1') default NULL,
  `auto_rescheduling_interval` int(8) default NULL,
  `auto_rescheduling_window` int(8) default NULL,
  `ochp_timeout` int(8) default NULL,
  `obsess_over_hosts` enum('0','1') default NULL,
  `ochp_command` int(11) unsigned default NULL,
  `check_host_freshness` enum('0','1') default NULL,
  `host_freshness_check_interval` int(8) default NULL,
  `service_freshness_check_interval` int(8) default NULL,
  `use_regexp_matching` enum('0','1') default NULL,
  `use_true_regexp_matching` enum('0','1') default NULL,
  `event_broker_options` varchar(5) default NULL,
  `daemon_dumps_core` enum('0','1') default NULL,
  `host_perfdata_command` int(11) unsigned default NULL,
  `service_perfdata_command` int(11) unsigned default NULL,
  `host_perfdata_file` text,
  `host_perfdata_file_template` text,
  `service_perfdata_file` text,
  `service_perfdata_file_template` text,
  `host_perfdata_file_mode` enum('a','w') default 'a',
  `service_perfdata_file_mode` enum('a','w') default 'a',
  `host_perfdata_file_processing_command` int(11) default NULL,
  `service_perfdata_file_processing_command` int(11) default NULL,
  `host_perfdata_file_processing_interval` int(5) default '0',
  `service_perfdata_file_processing_interval` int(5) default '0'
) DEFAULT CHARSET=utf8;

--
-- Dumping data for table `nagios_main`
--

ALTER TABLE nagios_main CHANGE COLUMN host_perfdata_template host_perfdata_file_template text;
ALTER TABLE nagios_main CHANGE COLUMN service_perfdata_template service_perfdata_file_template text;

ALTER TABLE nagios_main ADD COLUMN `ext_auth_type` enum('ad','ldap') default NULL;
ALTER TABLE nagios_main ADD COLUMN `ext_auth_base_dn` varchar(128) default NULL;
ALTER TABLE nagios_main ADD COLUMN `ext_auth_domain_controllers` varchar(64) default NULL;
ALTER TABLE nagios_main ADD COLUMN `ext_auth_ad_username` varchar(64) default NULL;
ALTER TABLE nagios_main ADD COLUMN `ext_auth_ad_password` varchar(64) default NULL;
ALTER TABLE nagios_main ADD COLUMN `ext_auth_suffix` varchar(64) default NULL;
ALTER TABLE nagios_main ADD COLUMN `ext_auth_ous` varchar(64) default NULL;
ALTER TABLE nagios_main ADD COLUMN `ext_auth_attr` enum('none','CN','UID') default NULL;
ALTER TABLE nagios_main ADD COLUMN `ext_auth_use_tls` enum('0','1') default NULL;
ALTER TABLE nagios_main ADD COLUMN `ext_auth_use_ssl` enum('0','1') default NULL;
ALTER TABLE nagios_main CHANGE COLUMN `ext_auth_type` `ext_auth_type` enum('ad','ldap','custom','searchbydn') default NULL;
ALTER TABLE nagios_main ADD COLUMN `ext_import_group` varchar(128) default NULL;

ALTER TABLE nagios_main ADD COLUMN `nedi_snmp_community` text default NULL;
ALTER TABLE nagios_main ADD COLUMN `nedi_seed_list` text default NULL;
ALTER TABLE nagios_main ADD COLUMN `nedi_netfilter` varchar(128) default '.';
ALTER TABLE nagios_main ADD COLUMN `nedi_timeout` varchar(32) default '10';

ALTER TABLE nagios_main ADD COLUMN `_ignored_objects_list` text default NULL;

ALTER TABLE nagios_main modify COLUMN ext_auth_base_dn varchar(256);
ALTER TABLE nagios_main modify COLUMN ext_auth_domain_controllers varchar(256);
ALTER TABLE nagios_main modify COLUMN ext_auth_ad_username varchar(256);
ALTER TABLE nagios_main modify COLUMN ext_auth_ad_password varchar(256);
ALTER TABLE nagios_main modify COLUMN ext_auth_suffix varchar(256);
ALTER TABLE nagios_main modify COLUMN ext_auth_ous varchar(256);
ALTER TABLE nagios_main ADD COLUMN _enable_eventguard enum('0','1');
ALTER TABLE nagios_main ADD COLUMN _enable_autodiscovery int(1) DEFAULT 1;
ALTER TABLE nagios_main ADD COLUMN _enable_autoimport int(1) DEFAULT 0;
ALTER TABLE nagios_main ADD COLUMN _interface_logo longblob DEFAULT NULL;
ALTER TABLE nagios_main ADD COLUMN _interface_theme varchar(256);
ALTER TABLE nagios_main ADD COLUMN _autoexport enum('0','1') DEFAULT '1';

ALTER TABLE nagios_main ADD COLUMN _sla_value float default 95;
ALTER TABLE nagios_main ADD COLUMN _sla_warning float default 98;

ALTER TABLE nagios_main ADD COLUMN _database_remote_connection enum('0','1') default '0';
ALTER TABLE nagios_main ADD COLUMN _allow_remove_user_comments ENUM('0', '1') DEFAULT '1' NOT NULL;

--
-- Table structure for table `nagios_main_desc`
--
CREATE TABLE `nagios_main_desc` (
  `field_name` text NOT NULL,
  `field_desc` text NOT NULL
) DEFAULT CHARSET=utf8;

--
-- Table structure for table `nagios_resources`
--
CREATE TABLE `nagios_resources` (
  `user1` text NOT NULL,
  `user2` text NOT NULL,
  `user3` text NOT NULL,
  `user4` text NOT NULL,
  `user5` text NOT NULL,
  `user6` text NOT NULL,
  `user7` text NOT NULL,
  `user8` text NOT NULL,
  `user9` text NOT NULL,
  `user10` text NOT NULL,
  `user11` text NOT NULL,
  `user12` text NOT NULL,
  `user13` text NOT NULL,
  `user14` text NOT NULL,
  `user15` text NOT NULL,
  `user16` text NOT NULL,
  `user17` text NOT NULL,
  `user18` text NOT NULL,
  `user19` text NOT NULL,
  `user20` text NOT NULL,
  `user21` text NOT NULL,
  `user22` text NOT NULL,
  `user23` text NOT NULL,
  `user24` text NOT NULL,
  `user25` text NOT NULL,
  `user26` text NOT NULL,
  `user27` text NOT NULL,
  `user28` text NOT NULL,
  `user29` text NOT NULL,
  `user30` text NOT NULL,
  `user31` text NOT NULL,
  `user32` text NOT NULL
) DEFAULT CHARSET=utf8;

--
-- Dumping data for table `nagios_resources`
--
ALTER TABLE nagios_resources MODIFY COLUMN user1 varchar(256);
ALTER TABLE nagios_resources MODIFY COLUMN user2 varchar(256);
ALTER TABLE nagios_resources MODIFY COLUMN user3 varchar(256);
ALTER TABLE nagios_resources MODIFY COLUMN user4 varchar(256);
ALTER TABLE nagios_resources MODIFY COLUMN user5 varchar(256);
ALTER TABLE nagios_resources MODIFY COLUMN user6 varchar(256);
ALTER TABLE nagios_resources MODIFY COLUMN user7 varchar(256);
ALTER TABLE nagios_resources MODIFY COLUMN user8 varchar(256);
ALTER TABLE nagios_resources MODIFY COLUMN user9 varchar(256);
ALTER TABLE nagios_resources MODIFY COLUMN user10 varchar(256);
ALTER TABLE nagios_resources MODIFY COLUMN user11 varchar(256);
ALTER TABLE nagios_resources MODIFY COLUMN user12 varchar(256);
ALTER TABLE nagios_resources MODIFY COLUMN user13 varchar(256);
ALTER TABLE nagios_resources MODIFY COLUMN user14 varchar(256);
ALTER TABLE nagios_resources MODIFY COLUMN user15 varchar(256);
ALTER TABLE nagios_resources MODIFY COLUMN user16 varchar(256);
ALTER TABLE nagios_resources MODIFY COLUMN user17 varchar(256);
ALTER TABLE nagios_resources MODIFY COLUMN user18 varchar(256);
ALTER TABLE nagios_resources MODIFY COLUMN user19 varchar(256);
ALTER TABLE nagios_resources MODIFY COLUMN user20 varchar(256);
ALTER TABLE nagios_resources MODIFY COLUMN user21 varchar(256);
ALTER TABLE nagios_resources MODIFY COLUMN user22 varchar(256);
ALTER TABLE nagios_resources MODIFY COLUMN user23 varchar(256);
ALTER TABLE nagios_resources MODIFY COLUMN user24 varchar(256);
ALTER TABLE nagios_resources MODIFY COLUMN user25 varchar(256);
ALTER TABLE nagios_resources MODIFY COLUMN user26 varchar(256);
ALTER TABLE nagios_resources MODIFY COLUMN user27 varchar(256);
ALTER TABLE nagios_resources MODIFY COLUMN user28 varchar(256);
ALTER TABLE nagios_resources MODIFY COLUMN user29 varchar(256);
ALTER TABLE nagios_resources MODIFY COLUMN user30 varchar(256);
ALTER TABLE nagios_resources MODIFY COLUMN user31 varchar(256);
ALTER TABLE nagios_resources MODIFY COLUMN user32 varchar(256);

--
-- Table structure for table `nagios_service_contactgroups`
--
CREATE TABLE `nagios_service_contactgroups` (
  `service_id` int(11) unsigned NOT NULL default '0',
  `contactgroup_id` int(11) unsigned NOT NULL default '0',
  PRIMARY KEY  (`service_id`,`contactgroup_id`)
) DEFAULT CHARSET=utf8;

--
-- Table structure for table `nagios_service_contacts`
--
CREATE TABLE `nagios_service_contacts` (
  `service_id` int(11) unsigned NOT NULL default '0',
  `contact_id` int(11) unsigned NOT NULL default '0',
  PRIMARY KEY  (`service_id`,`contact_id`),
  KEY  (`contact_id`, `service_id`)
) DEFAULT CHARSET=utf8;

--
-- Table structure for table `nagios_service_template_contactgroups`
--
CREATE TABLE `nagios_service_template_contactgroups` (
  `service_template_id` int(11) unsigned NOT NULL default '0',
  `contactgroup_id` int(11) unsigned NOT NULL default '0',
  PRIMARY KEY  (`service_template_id`,`contactgroup_id`)
) DEFAULT CHARSET=utf8;

--
-- Table structure for table `nagios_service_template_contacts`
--
CREATE TABLE `nagios_service_template_contacts` (
  `service_template_id` int(11) unsigned NOT NULL default '0',
  `contact_id` int(11) unsigned NOT NULL default '0',
  PRIMARY KEY  (`service_template_id`,`contact_id`),
  KEY  (`contact_id`, `service_template_id`)
) DEFAULT CHARSET=utf8;

--
-- Table structure for table `nagios_service_template_extended_info`
--

CREATE TABLE `nagios_service_template_extended_info` (
  `service_template_id` int(11) unsigned NOT NULL default '0',
  `notes` text,
  `notes_url` text,
  `action_url` text,
  `icon_image` text,
  `icon_image_alt` text,
  PRIMARY KEY  (`service_template_id`)
) DEFAULT CHARSET=utf8;

--
-- Table structure for table `nagios_service_templates`
--
CREATE TABLE `nagios_service_templates` (
  `service_template_id` int(11) unsigned NOT NULL auto_increment,
  `use_template_id` int(11) unsigned default NULL,
  `template_name` text NOT NULL,
  `template_description` text NOT NULL,
  `is_volatile` enum('0','1') default NULL,
  `check_command` int(11) default NULL,
  `max_check_attempts` int(2) default NULL,
  `normal_check_interval` int(8) default NULL,
  `retry_check_interval` int(2) default NULL,
  `active_checks_enabled` enum('0','1') default NULL,
  `passive_checks_enabled` enum('0','1') default NULL,
  `check_period` int(11) unsigned default NULL,
  `parallelize_check` enum('0','1') default NULL,
  `obsess_over_service` enum('0','1') default NULL,
  `check_freshness` enum('0','1') default NULL,
  `freshness_threshold` int(8) default NULL,
  `event_handler` int(11) unsigned default NULL,
  `event_handler_enabled` enum('0','1') default NULL,
  `low_flap_threshold` int(2) default NULL,
  `high_flap_threshold` int(2) default NULL,
  `flap_detection_enabled` enum('0','1') default NULL,
  `process_perf_data` enum('0','1') default NULL,
  `retain_status_information` enum('0','1') default NULL,
  `retain_nonstatus_information` enum('0','1') default NULL,
  `notification_interval` int(8) default NULL,
  `notification_period` int(11) unsigned default NULL,
  `notification_options_warning` enum('0','1') default NULL,
  `notification_options_unknown` enum('0','1') default NULL,
  `notification_options_critical` enum('0','1') default NULL,
  `notification_options_recovery` enum('0','1') default NULL,
  `notification_options_flapping` enum('0','1') default NULL,
  `notifications_enabled` enum('0','1') default NULL,
  `stalking_options_ok` enum('0','1') default NULL,
  `stalking_options_warning` enum('0','1') default NULL,
  `stalking_options_unknown` enum('0','1') default NULL,
  `stalking_options_critical` enum('0','1') default NULL,
  `failure_prediction_enabled` enum('0','1') default NULL,
  PRIMARY KEY  (`service_template_id`)
) DEFAULT CHARSET=utf8;

--
-- Dumping data for table `nagios_service_templates`
--
ALTER TABLE nagios_service_templates MODIFY COLUMN template_name varchar(128 UNIQUE);
DROP INDEX name ON nagios_service_templates;
ALTER TABLE nagios_service_templates MODIFY COLUMN template_description varchar(255);
ALTER TABLE nagios_service_templates ADD notification_options_downtime enum('0','1') default NULL;

--
-- Dumping data for table `nagios_services`
--
ALTER TABLE nagios_service_templates ADD COLUMN `baseline_enabled` enum('0','1') default '0';
ALTER TABLE nagios_service_templates MODIFY COLUMN `baseline_enabled` enum('0','1') default '0';
ALTER TABLE nagios_service_templates ADD COLUMN `baseline_seasonality` enum('0','1','2') default NULL;
ALTER TABLE nagios_service_templates MODIFY COLUMN `baseline_seasonality` enum('0','1','2') default NULL;
ALTER TABLE nagios_service_templates ADD COLUMN `baseline_time_window` int(11) default NULL;
ALTER TABLE nagios_service_templates MODIFY COLUMN `baseline_time_window` int(11) default NULL;
ALTER TABLE nagios_service_templates ADD COLUMN `baseline_method` int(2) default 0;
ALTER TABLE nagios_service_templates MODIFY COLUMN `baseline_method` int(2) default 0;
ALTER TABLE nagios_service_templates ADD COLUMN `baseline_multiply` int(2) default 2;
ALTER TABLE nagios_service_templates MODIFY COLUMN `baseline_multiply` int(2) default NULL;
ALTER TABLE nagios_service_templates MODIFY COLUMN `baseline_time_window` int(2) default NULL;

--
-- Table structure for table `nagios_servicegroup_membership`
--
CREATE TABLE `nagios_servicegroup_membership` (
  `service_id` int(11) unsigned NOT NULL default '0',
  `servicegroup_id` int(11) unsigned NOT NULL default '0'
) DEFAULT CHARSET=utf8;

--
-- Table structure for table `nagios_servicegroup_template_membership`
--
CREATE TABLE `nagios_servicegroup_template_membership` (
  `service_template_id` int(11) unsigned NOT NULL default '0',
  `servicegroup_id` int(11) unsigned NOT NULL default '0'
) DEFAULT CHARSET=utf8;

--
-- Table structure for table `nagios_servicegroups`
--
CREATE TABLE `nagios_servicegroups` (
  `servicegroup_id` int(11) unsigned NOT NULL auto_increment,
  `servicegroup_name` text NOT NULL,
  `alias` text NOT NULL,
  PRIMARY KEY  (`servicegroup_id`)
) DEFAULT CHARSET=utf8;

--
-- Dumping data for table `nagios_servicegroups`
--
ALTER TABLE nagios_servicegroups MODIFY COLUMN servicegroup_name varchar(128) UNIQUE;
DROP INDEX name ON nagios_servicegroups;
ALTER TABLE nagios_servicegroups MODIFY COLUMN alias varchar(255);

--
-- Table structure for table `nagios_servicegroups_desc`
--
CREATE TABLE `nagios_servicegroups_desc` (
  `field_name` text NOT NULL,
  `field_desc` text NOT NULL
) DEFAULT CHARSET=utf8;

--
-- Table structure for table `nagios_services`
--
CREATE TABLE `nagios_services` (
  `service_id` int(11) unsigned NOT NULL auto_increment,
  `use_template_id` int(11) default NULL,
  `service_description` text NOT NULL,
  `is_volatile` enum('0','1') default NULL,
  `check_command` int(11) default NULL,
  `max_check_attempts` int(2) default NULL,
  `normal_check_interval` int(8) default NULL,
  `retry_check_interval` int(2) default NULL,
  `active_checks_enabled` enum('0','1') default NULL,
  `passive_checks_enabled` enum('0','1') default NULL,
  `check_period` int(11) unsigned default NULL,
  `parallelize_check` enum('0','1') default NULL,
  `obsess_over_service` enum('0','1') default NULL,
  `check_freshness` enum('0','1') default NULL,
  `freshness_threshold` int(8) default NULL,
  `event_handler` int(11) unsigned default NULL,
  `event_handler_enabled` enum('0','1') default NULL,
  `low_flap_threshold` int(2) default NULL,
  `high_flap_threshold` int(2) default NULL,
  `flap_detection_enabled` enum('0','1') default NULL,
  `process_perf_data` enum('0','1') default NULL,
  `retain_status_information` enum('0','1') default NULL,
  `retain_nonstatus_information` enum('0','1') default NULL,
  `notification_interval` int(8) default NULL,
  `notification_period` int(11) unsigned default NULL,
  `notification_options_warning` enum('0','1') default NULL,
  `notification_options_unknown` enum('0','1') default NULL,
  `notification_options_critical` enum('0','1') default NULL,
  `notification_options_recovery` enum('0','1') default NULL,
  `notification_options_flapping` enum('0','1') default NULL,
  `notifications_enabled` enum('0','1') default NULL,
  `stalking_options_ok` enum('0','1') default NULL,
  `stalking_options_warning` enum('0','1') default NULL,
  `stalking_options_unknown` enum('0','1') default NULL,
  `stalking_options_critical` enum('0','1') default NULL,
  `host_id` int(11) default NULL,
  `host_template_id` int(11) default NULL,
  `hostgroup_id` int(11) unsigned default NULL,
  `failure_prediction_enabled` enum('0','1') default NULL,
  PRIMARY KEY  (`service_id`)
) DEFAULT CHARSET=utf8;

--
-- Dumping data for table `nagios_services`
--
ALTER TABLE nagios_services MODIFY COLUMN service_description varchar(128);
ALTER TABLE nagios_services ADD COLUMN `nedi_ifspeed` int(11) default NULL;
ALTER TABLE nagios_services ADD COLUMN `nedi_ifcir` int(11) default NULL;
UPDATE nagios_services SET service_description=trim(service_description);

ALTER TABLE nagios_services ADD COLUMN `_baseline_enabled` enum('0','1') default '0';
ALTER TABLE nagios_services CHANGE COLUMN _baseline_enabled baseline_enabled enum('0','1') default '0';
ALTER TABLE nagios_services MODIFY COLUMN `baseline_enabled` enum('0','1') default NULL;

ALTER TABLE nagios_services ADD COLUMN `_baseline_seasonality` enum('0','1','2') default NULL;
ALTER TABLE nagios_services CHANGE COLUMN _baseline_seasonality baseline_seasonality  enum('0','1','2') default '0';
ALTER TABLE nagios_services MODIFY COLUMN baseline_seasonality  enum('0','1','2') default NULL;

ALTER TABLE nagios_services ADD COLUMN `_baseline_time_window` int(11) default NULL;
ALTER TABLE nagios_services CHANGE COLUMN _baseline_time_window baseline_time_window  int(2);
ALTER TABLE nagios_services MODIFY COLUMN baseline_time_window  int(2) default NULL;

ALTER TABLE nagios_services ADD COLUMN `baseline_method` int(2) default NULL;
ALTER TABLE nagios_services MODIFY COLUMN `baseline_method` int(2) default NULL;
ALTER TABLE nagios_services ADD COLUMN `baseline_multiply` int(2) default NULL;
ALTER TABLE nagios_services MODIFY COLUMN `baseline_multiply` int(2) default NULL;

ALTER TABLE nagios_services DROP COLUMN _baseline_enabled;
ALTER TABLE nagios_services DROP COLUMN _baseline_seasonality;
/*ALTER TABLE nagios_services  DROP COLUMN _baseline_time_window;*/

ALTER TABLE nagios_services MODIFY COLUMN `baseline_time_window` int(2) default 5;

ALTER TABLE nagios_services ADD notification_options_downtime enum('0','1') default NULL;

ALTER TABLE nagios_services ADD COLUMN `created` TIMESTAMP DEFAULT CURRENT_TIMESTAMP;
UPDATE nagios_services SET created=CURRENT_TIMESTAMP WHERE created='0000-00-00 00:00:00';

--
-- Table structure for table `nagios_services_check_command_parameters`
--
CREATE TABLE `nagios_services_check_command_parameters` (
  `checkcommandparameter_id` int(11) unsigned NOT NULL auto_increment,
  `service_id` int(11) unsigned default NULL,
  `service_template_id` int(11) unsigned default NULL,
  `parameter` text NOT NULL,
  PRIMARY KEY  (`checkcommandparameter_id`)
) DEFAULT CHARSET=utf8;

--
-- Dumping data for table `nagios_services_check_command_parameters`
--
ALTER TABLE nagios_services_check_command_parameters CHANGE parameter parameter text;

--
-- Table structure for table `nagios_services_desc`
--
CREATE TABLE `nagios_services_desc` (
  `field_name` text NOT NULL,
  `field_desc` text NOT NULL
) DEFAULT CHARSET=utf8;

--
-- Table structure for table `nagios_services_extended_info`
--
CREATE TABLE `nagios_services_extended_info` (
  `service_id` int(11) unsigned NOT NULL default '0',
  `notes` text,
  `notes_url` text,
  `action_url` text,
  `icon_image` text,
  `icon_image_alt` text,
  PRIMARY KEY  (`service_id`)
) DEFAULT CHARSET=utf8;

--
-- Table structure for table `nagios_services_extended_info_desc`
--
CREATE TABLE `nagios_services_extended_info_desc` (
  `field_name` text NOT NULL,
  `field_desc` text NOT NULL
) DEFAULT CHARSET=utf8;

--
-- Table structure for table `nagios_timeperiods`
--
CREATE TABLE `nagios_timeperiods` (
  `timeperiod_id` int(11) unsigned NOT NULL auto_increment,
  `network_id` int(11) unsigned NOT NULL default '0',
  `timeperiod_name` text NOT NULL,
  `alias` text NOT NULL,
  `sunday` text NOT NULL,
  `monday` text NOT NULL,
  `tuesday` text NOT NULL,
  `wednesday` text NOT NULL,
  `thursday` text NOT NULL,
  `friday` text NOT NULL,
  `saturday` text NOT NULL,
  PRIMARY KEY  (`timeperiod_id`)
) DEFAULT CHARSET=utf8;

--
-- Dumping data for table `nagios_timeperiods`
--
DROP INDEX name ON nagios_timeperiods;
ALTER TABLE nagios_timeperiods MODIFY COLUMN timeperiod_name varchar(128) UNIQUE;

--
-- Table structure for table `nagios_timeperiods_desc`
--
CREATE TABLE `nagios_timeperiods_desc` (
  `field_name` text NOT NULL,
  `field_desc` text NOT NULL
) DEFAULT CHARSET=utf8;

--
-- Table structure for table `sessions`
--
CREATE TABLE `sessions` (
  `SESSKEY` varchar(32) NOT NULL default '',
  `EXPIRY` int(11) unsigned NOT NULL default '0',
  `SESSIONDATA` binary(1) NOT NULL default '\0',
  PRIMARY KEY  (`SESSKEY`),
  KEY `EXPIRY` (`EXPIRY`)
) DEFAULT CHARSET=utf8;

--
-- Create indexes to speed up querys
--
CREATE INDEX hosts_parents ON nagios_hosts (host_name(128), parents);
CREATE INDEX parent_host ON nagios_hosts (parents,host_name(128));
CREATE INDEX use_template_id ON nagios_hosts (use_template_id);
CREATE INDEX id on nagios_host_templates (use_template_id);
CREATE INDEX id on nagios_service_templates (use_template_id);
CREATE INDEX child_parent on nagios_host_parents (child_id,parent_id);
CREATE INDEX parent_child on nagios_host_parents (parent_id,child_id);
CREATE INDEX id_name on nagios_services (service_id, service_description(128));
CREATE INDEX name_id on nagios_services (service_description(128),service_id);
CREATE INDEX template_id_name on nagios_services (host_template_id, service_description(128));
CREATE INDEX name_template_id on nagios_services (service_description(128),host_template_id);
CREATE INDEX hostgroup_id_name on nagios_services (hostgroup_id, service_description(128));
CREATE INDEX name_hostgroup_id on nagios_services (service_description(128),hostgroup_id);
CREATE INDEX use_id on nagios_services (use_template_id);
CREATE INDEX host_id on nagios_services (host_id, service_id);
CREATE INDEX host_template_id on nagios_services (host_template_id);
CREATE INDEX contactgroup_contact on nagios_contactgroup_membership (contactgroup_id, contact_id);
CREATE INDEX contact_contactgroup on nagios_contactgroup_membership (contact_id, contactgroup_id);
CREATE INDEX host_id on nagios_hosts_check_command_parameters (host_id, checkcommandparameter_id);
CREATE INDEX host_template_id on nagios_hosts_check_command_parameters (host_template_id, checkcommandparameter_id);
CREATE INDEX contact_id on nagios_contact_addresses (contact_id);
CREATE INDEX host_id on nagios_hostgroup_membership (host_id, hostgroup_id);
CREATE INDEX hostgroup_id on nagios_hostgroup_membership (hostgroup_id, host_id);
CREATE INDEX host_template_id on nagios_hostgroup_template_membership (host_template_id,hostgroup_id);
CREATE INDEX service_id on nagios_service_contactgroups (service_id);
CREATE INDEX contactgroup_id on nagios_service_contactgroups (contactgroup_id, service_id);
CREATE INDEX service_id on nagios_servicegroup_membership (service_id);
CREATE INDEX servicegroup_id on nagios_servicegroup_membership (servicegroup_id, service_id);
CREATE INDEX host_template_id on nagios_host_template_contactgroups (host_template_id);
CREATE INDEX contactgroup_id on nagios_host_template_contactgroups (contactgroup_id,host_template_id);
CREATE INDEX service_template_id on nagios_services_check_command_parameters (service_template_id, checkcommandparameter_id);
CREATE INDEX service_template_id on nagios_escalations (service_template_id, escalation_description(128), service_id);
CREATE INDEX host_template_id on nagios_escalations (host_template_id, escalation_description(128), service_id);
CREATE INDEX host_id on nagios_escalations (host_id, escalation_description(128), service_id);
CREATE INDEX host_template_id on nagios_dependencies (host_template_id, service_id);
CREATE INDEX service_template_id on nagios_dependencies (service_template_id);
CREATE INDEX host_id on nagios_dependencies (host_id,target_host_id);
CREATE INDEX service_id on nagios_dependencies (service_id,target_host_id);
CREATE INDEX service_template_id on nagios_service_template_contactgroups (service_template_id);
CREATE INDEX contactgroup_id on nagios_service_template_contactgroups (contactgroup_id,service_template_id);
CREATE INDEX service_template_id on nagios_servicegroup_template_membership (service_template_id);
CREATE INDEX servicegroup_id on nagios_servicegroup_template_membership (servicegroup_id,service_template_id);
CREATE INDEX escalation_id on nagios_escalation_contactgroups (escalation_id);
CREATE INDEX contactgroup_id on nagios_escalation_contactgroups (contactgroup_id, escalation_id);
CREATE INDEX contactgroup_id on nagios_host_contactgroups (contactgroup_id, host_id);

--
-- Add column `in_map` to the nagios_servicegroups
--

ALTER TABLE nagios_servicegroups ADD COLUMN in_map int(11) DEFAULT NULL;

--
-- Table structure for table `nagios_languages`
--

CREATE TABLE `nagios_languages` (
  `language_id` int(11) unsigned NOT NULL auto_increment,
  `locale_name` varchar(32) UNIQUE NOT NULL,
  `alias` varchar(255) NOT NULL,
  PRIMARY KEY  (`language_id`)
) DEFAULT CHARSET=utf8;

--
-- Insert some data to nagios_languages
--
INSERT INTO nagios_languages(locale_name, alias) VALUES ( 'pt_BR', 'Portugues do Brasil' );
INSERT INTO nagios_languages(locale_name, alias) VALUES ( 'en', 'English' );

--
-- Modifications to be compatible with Nagios 3.x
--

ALTER TABLE nagios_main DROP column `aggregate_status_updates`;
ALTER TABLE nagios_main DROP column `downtime_file`;
ALTER TABLE nagios_main DROP column `comment_file`;

ALTER TABLE nagios_main ADD column `free_child_process_memory` enum('0','1') NOT NULL default '1';
ALTER TABLE nagios_main ADD column `enable_environment_macros` enum('0','1') NOT NULL default '1';
ALTER TABLE nagios_main ADD column `use_large_installation_tweaks` enum('0','1') NOT NULL default '1';
alter table nagios_main modify column service_interleave_factor varchar(5);

--
-- Escalation constraint to keep data integrity
--

-- alter table nagios_escalation_contactgroups add FOREIGN KEY (escalation_id) references nagios_escalations(escalation_id) ON DELETE CASCADE;

--
-- NEW Modifications to be compatible with Nagios 3.x
--

ALTER TABLE nagios_main ADD column `check_result_reaper_frequency` int(11) NOT NULL default 5;
ALTER TABLE nagios_main ADD column `max_check_result_reaper_time` int(11) NOT NULL default 30;
ALTER TABLE nagios_main ADD column `check_result_path` varchar(128) NOT NULL default '/usr/local/opmon/var/spool/checkresults';
ALTER TABLE nagios_main ADD column `max_check_result_file_age` int(11) NOT NULL default 0;
ALTER TABLE nagios_main ADD column `enable_predictive_host_dependency_checks` enum('0','1') NOT NULL default '1';
ALTER TABLE nagios_main ADD column `enable_predictive_service_dependency_checks` enum('0','1') NOT NULL default '1';
ALTER TABLE nagios_main ADD column `cached_host_check_horizon` int(11) NOT NULL default 0;
ALTER TABLE nagios_main ADD column `cached_service_check_horizon` int(11) NOT NULL default 0;
ALTER TABLE nagios_main ADD column `check_for_orphaned_hosts` enum('0','1') NOT NULL default '1';
ALTER TABLE nagios_main ADD column `enable_embedded_perl` enum('0','1') NOT NULL default '0';
ALTER TABLE nagios_main ADD column `use_embedded_perl_implicitly` enum('0','1') NOT NULL default '0';

ALTER TABLE nagios_main DROP column `service_reaper_frequency`;
ALTER TABLE nagios_main DROP column `freshness_check_interval`;
ALTER TABLE nagios_main DROP column `daemon_dumps_core`;
ALTER TABLE nagios_main DROP column `p1_file`;


--
-- Centralized User Control
--

DROP TABLE nagios_languages;

--
-- DEBUG Options
--

ALTER TABLE `nagios_main` ADD COLUMN `debug_file` varchar(255) NOT NULL DEFAULT '/usr/local/opmon/var/opmon.debug';
ALTER TABLE `nagios_main` ADD COLUMN `debug_level` varchar(5) NOT NULL DEFAULT '0';
ALTER TABLE `nagios_main` ADD COLUMN `debug_verbosity` varchar(5) NOT NULL DEFAULT '0';

--
-- Fix retained information
--

UPDATE `nagios_main` SET use_retained_scheduling_info = '1';
UPDATE `nagios_main` SET use_retained_program_state = '1';
UPDATE `nagios_main` SET service_inter_check_delay_method = 'n';
UPDATE `nagios_main` SET host_inter_check_delay_method = 'n';

--
-- Job Servers
--

CREATE TABLE `job_servers` (
  `server_id` int(11) unsigned NOT NULL auto_increment,
  `server` varchar(32) NOT NULL default 'localhost',
  PRIMARY KEY  (`server_id`),
  UNIQUE KEY `server_id` (`server_id`,`server`)
) DEFAULT CHARSET=utf8;

--
-- Incremental Export
--

CREATE TABLE `incremental_export` (
  `type` int(11) NOT NULL,
  `object_action` int(11) NOT NULL,
  `id` int(11) NOT NULL,
  `contact_name` varchar(64) NOT NULL,
  PRIMARY KEY  (`type`,`object_action`,`id`)
) DEFAULT CHARSET=utf8;

--
-- Scat types
--

CREATE TABLE `scat_types` (
  `scat_type_id` int(11) unsigned NOT NULL auto_increment,
  `scat_type_name` varchar(64) NOT NULL,
  `host_id` int(11) DEFAULT NULL,
  `host_template_id` int(11) NOT NULL,
  `service_template_id` int(11) NOT NULL,
  PRIMARY KEY (`scat_type_id`,`scat_type_name`)
) DEFAULT CHARSET=utf8;

--
-- Table to keep export log
--

CREATE TABLE export_log (
  `entry_time` datetime NOT NULL default '0000-00-00 00:00:00',
  `is_running` enum('0','1') default '0',
  `data` text DEFAULT NULL
) DEFAULT CHARSET=utf8;

--
-- Table to keep information about which group this contact was imported
--

CREATE TABLE `opmon_contacts_imported` (
  `contact_id` int(11) unsigned UNIQUE NOT NULL,
  `external_group_name` varchar(128) NOT NULL
) DEFAULT CHARSET=utf8;

--
-- Initial value for scat_types
--

USE `opcfg`;
alter table scat_types modify `scat_type_id` int(11) unsigned NOT NULL auto_increment unique;
SET SESSION sql_mode='NO_AUTO_VALUE_ON_ZERO';
insert into scat_types values (1,'IT',NULL,(select host_template_id from nagios_host_templates limit 1),(select service_template_id from nagios_service_templates limit 1));
insert into scat_types values (2,'Business',NULL,(select host_template_id from nagios_host_templates limit 1),(select service_template_id from nagios_service_templates limit 1));
insert into scat_types values (3,'Vital business',NULL,(select host_template_id from nagios_host_templates limit 1),(select service_template_id from nagios_service_templates limit 1));
SET SESSION sql_mode='';

--
-- Eventguard Config not need anymore
-- using jobservers form mod_gearman
-- and enable disable at nagios_main
--
DROP TABLE opmon_eventguard;

CREATE TABLE `snmp_communities` (
  `community_id` int(11) unsigned NOT NULL auto_increment,
  `snmp_version` varchar(3) NOT NULL,
  `community` varchar(128) default NULL,
  `authentication_protocol` varchar(3) default NULL,
  `authentication_passphrase` varchar(128) default NULL,
  `security_level` varchar(12) default NULL,
  `context_name` varchar(128) default NULL,
  `security_username` varchar(128) default NULL,
  `privacy_protocol` varchar(3) default NULL,
  `privacy_protocol_passphrase` varchar(128) default NULL,
  `destination_engine` varchar(128) default NULL,
  `active` int(1) default 1,
  PRIMARY KEY  (`community_id`)
) DEFAULT CHARSET=utf8;

CREATE TABLE `nedi_ignored_list` (
  `ip_id` int(11) unsigned NOT NULL auto_increment,
  `ip` varchar(30) default NULL,
  PRIMARY KEY  (`ip_id`)
) DEFAULT CHARSET=utf8;

CREATE TABLE `nedi_seed_list` (
  `ip_id` int(11) unsigned NOT NULL auto_increment,
  `ip` varchar(30) default NULL,
  PRIMARY KEY  (`ip_id`)
) DEFAULT CHARSET=utf8;

CREATE TABLE `discovered_objects` (
  `discovery_id` int(11) auto_increment PRIMARY KEY,
  `host_name` varchar(128) default NULL,
  `data` blob,
  UNIQUE KEY `idx_host_name` (`host_name`(128))
) DEFAULT CHARSET=utf8;
ALTER TABLE discovered_objects MODIFY data LONGBLOB;

CREATE TABLE `discovery_cache` (
  `key` varchar(256) default NULL,
  `data` blob
) DEFAULT CHARSET=utf8;
ALTER TABLE `discovery_cache` MODIFY `data` LONGBLOB;

CREATE TABLE `model_service` (
  `modelgroup_id` varchar(512) default NULL,
  `model_id` varchar(512) default NULL,
  `service_id` int(11) default NULL
) DEFAULT CHARSET=utf8;

CREATE TABLE `discovered_objects_ips` (
	  `host_name` varchar(128) default NULL,
	  `ip` varchar(15) default NULL
) DEFAULT CHARSET=utf8;

CREATE TABLE `credentials` (
  `credential_id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `domain` varchar(100) DEFAULT NULL,
  `username` varchar(100) NOT NULL,
  `password` varchar(100) NOT NULL,
  `active` int(1) DEFAULT '1',
  PRIMARY KEY (`credential_id`)
) DEFAULT CHARSET=utf8;

-- Create user for external database access 
GRANT SELECT ON *.* to opreports@'localhost' IDENTIFIED BY 'opmon';

UPDATE nagios_contacts SET language='en_US' WHERE language='es_ES' OR language='en_US_ITIL' OR language='es_ES_ITIL';

CREATE TABLE `baseline` (
  `id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(128) DEFAULT NULL,
  `description` varchar(128) DEFAULT NULL,
  `type` tinyint(4) DEFAULT '0',
  `samples` int(11) DEFAULT '5',
  `alarm` tinyint(4) DEFAULT '3',
  `multiply_up` double DEFAULT NULL,
  `multiply_down` double DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `id_name` (`name`),
  KEY `id_type` (`type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE `baseline_calendar` (
  `baseline_id` int(11) NOT NULL DEFAULT '0',
  `date` date NOT NULL DEFAULT '0000-00-00',
  `util` varchar(128) DEFAULT NULL,
  `alarm` tinyint(4) DEFAULT '3',
  `samples` int(11) DEFAULT '5',
  `multiply_up` double DEFAULT NULL,
  `multiply_down` double DEFAULT NULL,
  PRIMARY KEY (`baseline_id`,`date`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS `opcfg`.`model` (
  `model_id` INT(11) NOT NULL AUTO_INCREMENT,
  `model_data` BLOB NOT NULL,
  `model_name` VARCHAR(128) NOT NULL,
  `model_version` VARCHAR(128) NOT NULL,
  PRIMARY KEY (`model_id`))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;

CREATE TABLE IF NOT EXISTS `opcfg`.`model_association` (
  `model_association_id` INT(11) NOT NULL AUTO_INCREMENT,
  `model_id` INT(11) NOT NULL,
  `service_id` INT(11) NOT NULL,
  PRIMARY KEY (`model_association_id`))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;

CREATE TABLE IF NOT EXISTS `opcfg`.`onc_tokens` (
  `id` INT(11) NOT NULL AUTO_INCREMENT,
  `token` VARCHAR(512) NOT NULL,
  `contact_id` INT(11) NOT NULL,
  PRIMARY KEY (`id`))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;

